Welcome to ClientVPS Mirrors

Help for package eAnalytics
Version: 0.3.1
Title: Dynamic Web-Based Analytics for the Energy Industry
Description: A 'Shiny' web application for energy industry analytics. Take an overview of the industry, measure Key Performance Indicators, identify changes in the industry over time, and discover new relationships in the data.
URL: http://paulgovan.github.io/eAnalytics/, https://github.com/paulgovan/eAnalytics
BugReports: https://github.com/paulgovan/eAnalytics/issues
Depends: R (≥ 2.10.0),
License: Apache License version 1.1 | Apache License version 2.0 [expanded from: Apache License]
Imports: dplyr, DT, energyr, googleVis, leaflet, plotly (≥ 4.5.2), shiny, shinydashboard, shinyWidgets
Encoding: UTF-8
RoxygenNote: 7.2.3
Suggests: knitr, rmarkdown
NeedsCompilation: no
Packaged: 2024-09-11 15:27:59 UTC; paulgovan
Author: Paul Govan ORCID iD [aut, cre, cph]
Maintainer: Paul Govan <paul.govan2@gmail.com>
Repository: CRAN
Date/Publication: 2024-09-12 23:00:02 UTC

Interactive and dynamic web analytics for the energy industry.

Description

eAnalytics is a shiny web application for energy industry analytics. eAnalytics has the largest open database of US energy industry information, providing interactive and dynamic web analytics to industry stakeholders.

Usage

eAnalytics()

See Also

http://paulgovan.github.io/eAnalytics/

Examples

if (interactive()) {
  eAnalytics()
}

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.