| Version: | 0.4 |
| Title: | Dynamic Web-Based Analytics for the Energy Industry |
| Description: | A 'Shiny' web application for energy industry analytics. Take an overview of the industry, measure Key Performance Indicators, identify changes in the industry over time, and discover new relationships in the data. |
| URL: | http://paulgovan.github.io/eAnalytics/, https://github.com/paulgovan/eAnalytics |
| BugReports: | https://github.com/paulgovan/eAnalytics/issues |
| Depends: | R (≥ 2.10.0), |
| License: | Apache License version 1.1 | Apache License version 2.0 [expanded from: Apache License] |
| Imports: | dplyr, DT, energyr, googleVis, leaflet, plotly (≥ 4.5.2), shiny, shinydashboard, shinyWidgets |
| Encoding: | UTF-8 |
| RoxygenNote: | 7.3.3 |
| Suggests: | knitr, rmarkdown, shinytest2, testthat (≥ 3.0.0) |
| VignetteBuilder: | knitr |
| Config/testthat/edition: | 3 |
| NeedsCompilation: | no |
| Packaged: | 2026-05-19 20:22:26 UTC; paulgovan |
| Author: | Paul Govan |
| Maintainer: | Paul Govan <paul.govan2@gmail.com> |
| Repository: | CRAN |
| Date/Publication: | 2026-05-19 20:40:02 UTC |
eAnalytics: Dynamic Web-Based Analytics for the Energy Industry
Description
A 'Shiny' web application for energy industry analytics. Take an overview of the industry, measure Key Performance Indicators, identify changes in the industry over time, and discover new relationships in the data.
Author(s)
Maintainer: Paul Govan paul.govan2@gmail.com (ORCID) [copyright holder]
See Also
Useful links:
Report bugs at https://github.com/paulgovan/eAnalytics/issues
Launch eAnalytics Shiny Application
Description
This function launches the eAnalytics Shiny application, which provides interactive visualizations and analyses of energy data. The application includes features such as time series plots, motion charts, data tables, and geographic maps.
Usage
eAnalytics()
Value
The function does not return a value; it launches the Shiny app.
See Also
http://paulgovan.github.io/eAnalytics/
Examples
if (interactive()) {
eAnalytics()
}