| Title: | Dynamic Web-Based Analytics for the Energy Industry |
|---|---|
| Description: | A 'Shiny' web application for energy industry analytics. Take an overview of the industry, measure Key Performance Indicators, identify changes in the industry over time, and discover new relationships in the data. |
| Authors: | Paul Govan [aut, cre, cph] (ORCID: <https://orcid.org/0000-0002-1821-8492>) |
| Maintainer: | Paul Govan <[email protected]> |
| License: | Apache License |
| Version: | 0.4 |
| Built: | 2026-05-19 20:34:59 UTC |
| Source: | https://github.com/paulgovan/eanalytics |
This function launches the eAnalytics Shiny application, which provides interactive visualizations and analyses of energy data. The application includes features such as time series plots, motion charts, data tables, and geographic maps.
eAnalytics()eAnalytics()
The function does not return a value; it launches the Shiny app.
http://paulgovan.github.io/eAnalytics/
if (interactive()) { eAnalytics() }if (interactive()) { eAnalytics() }